@@ -257,7 +257,6 @@ SYSTEM_SOURCE_SYSTEM: OntologyPropertyReference = OntologyPropertyReference('wac
 SYSTEM_SOURCE_REFERENCE_ID: OntologyPropertyReference = OntologyPropertyReference('wacom', 'core', 'sourceReferenceId')
 
 
-
 class OntologyClass(OntologyObject):
     """
     OntologyClass
@@ -646,6 +645,54 @@ class Ontology(object):
         """All classes."""
         return list(self.__classes.values())
 
+    def get_class(self, class_reference: OntologyClassReference) -> Optional[OntologyClass]:
+        """
+        Get class instance by reference.
+
+        Parameters
+        ----------
+        class_reference: OntologyClassReference
+            Class reference
+
+        Returns
+        --------
+        instance: Optional[OntologyClass]
+            Instance of ontology class.
+        """
+        return self.__classes.get(class_reference)
+
+    def get_object_properties(self, property_reference: OntologyPropertyReference) -> Optional[OntologyProperty]:
+        """
+        Get object property instance by reference.
+
+        Parameters
+        ----------
+        property_reference: OntologyPropertyReference
+            Property reference
+
+        Returns
+        --------
+        instance: Optional[OntologyProperty]
+            Instance of ontology object property.
+        """
+        return self.__object_properties.get(property_reference)
+
+    def get_data_properties(self, property_reference: OntologyPropertyReference) -> Optional[OntologyProperty]:
+        """
+        Get object property instance by reference.
+
+        Parameters
+        ----------
+        property_reference: OntologyPropertyReference
+            Property reference
+
+        Returns
+        --------
+        instance: Optional[OntologyProperty]
+            Instance of ontology object property.
+        """
+        return self.__data_properties.get(property_reference)
+
 
 class ThingObject(abc.ABC):
     """
